# Changelog

All notable changes to this project will be documented in this file.

## [0.0.1] - 2024-12-27

### 🐛 Bug Fixes

- Lint fixed and mypy errors fixed
- Fixing pre-commit errors again again again :(
- Fixing skip integration tests if no env vars are set
- Fixing skip integration tests if no env vars are set and changelog updated
- Pytest cov workflow fixed
- Codecov target fixed

### 📚 Documentation

- Updated readme
- Codecov badge fixed
- Build workflow badge fixed and readme table fixed
- License fixed
- Fixed license badge in readme

### 🧪 Testing

- Writing tests. added tests for utils and Ethereum types
- Test updated again

### ⚙️ Miscellaneous Tasks

- Initial project files added
- Code refactored and somewhat working condition
- Testing
- Working phew
- Pyproject.toml & env.example updated
- Refactoring in progress. breaking changes
- Phew code refacored and finally working without ape
- Updated changelog
- Updated changelog
- Github actions updated
- Changelog updated

<!-- generated by git-cliff -->
